FUNCTION filters,n,filtertype,bandtype,cutoff,order,bandwidth
;
;CONSTRUCTION OF 1-D BUTTERWORTH OR EXPONENTIAL FILTERS
;Derived from \idl\lib\xdemo\fourierd.pro
;
;CALLING SEQUENCE: 
; filter=filters(n,filtertype,bandtype,cutoff,order,bandwidth)
;
; n = array length (including replication)
;
; filtertype = 0 - Butterworth filter
;	       1 - Exponential filter
;
; bandtype   = 0 - lowpass
;	       1 - highpass
;	       2 - bandpass
;	       3 - bandreject
;
; cutoff, order, bandwidth - filter parameters (in pixels)

if n_params() eq 6 then goto,good
bad:
  print,'U s a g e :'
  print,'FILTER = filters (n,filtertype,bandtype,cutoff,order,bandwidth)'
  print,' '
  print,'n = array length (including replication)'
  print,'filtertype = 0 (Butterworth) or 1 (Exponential)'
  print,'bandtype = 0 (lowps), 1 (highps), 2 (bandps), 3 (bandreject)'
  RETURN,0

good:
if (filtertype gt 1) or (bandtype gt 3) then goto,bad

  distfun = FINDGEN(n)			;compute a single dimensional
  distfun = distfun < (n - distfun)	;euclidean distance function
  distfun(0) = 1e-4				;Avoid division by 0

CASE filtertype OF

  0: BEGIN					;Butterworth filter
	IF(bandtype EQ 0) THEN $		;lowpass
	  filter = 1.0 / (1.0 + (distfun / cutoff)^(2 * order)) $
	ELSE IF(bandtype EQ 1) THEN $		;highpass
	  filter = 1.0 / (1.0 + (cutoff / distfun)^(2 * order)) $
	ELSE BEGIN
	  filter = distfun * distfun - cutoff^2  ;Dist squared
	  zeroes = where(filter eq 0.0, count)
	  if count ne 0 then filter(zeroes) = 1e-6  ;Avoid divide by 0
	    filter = 1.0 / (1.0 + ((distfun*bandwidth)/ filter) $
			^ (2 * order))
	  IF (bandtype eq 2) then filter = 1.0 - filter; bandpass
	ENDELSE
     END


  1: BEGIN					;Exponential filter
	   IF(bandtype EQ 0) THEN $		;lowpass
	     filter = exp((-(distfun / cutoff)^order)) $
	   ELSE IF(bandtype EQ 1) THEN $	;highpass
	     filter = 1.0 - exp((-(distfun / cutoff)^order)) $
	   ELSE BEGIN	;Bandpass / reject,  avoid underflow in exp fcn
	     filter = (distfun * distfun - cutoff^2) / (distfun * bandwidth)
	     filter = exp(-(filter ^ (2 * order) < 25))
	     IF(bandtype EQ 3) THEN filter = 1.0 - filter ;bandreject
	   ENDELSE
     END
ENDCASE

window,2
plot,filter(0:n/2),back=255,col=0,title='FILTER'
RETURN,filter

END
