pro ifte,farr,result
;
; Evaluation of data obtained by IFT (Individual Feature Tracking).
; Calculation of velocities, fourier filtering.
; Intensity is not filtered.
; Input:  farr = output array from IFT (seq.no,x-pos,y-pos,intensity)
; Output: result = array(8,n), where n is a number of successfuly tracked
;	positions. Each row contains:
;  (0)seq.no, (1)x-pos, (2)y-pos, (3)time, (4)Vx, (5)Vy, (6)velocity, (7)intensity

;-------------- TUNABLE PARAMETER -------------------------------------------------
scale = 0.02587*725    ; spatial scale (km/pixel)
dtim = 1.              ; time difference between frames in seconds
;----------------------------------------------------------------------------------

s=size(farr) & n=s(2)	; no. of positions

; time (equidistant sampling)
;read,'Time difference between frames in seconds:',dtim
tim=findgen(n)*dtim	; tim(0)=0

;  time differences in seconds - time [hours] read from vy08(1,*)
;  tim=(vy08(1,farr(0,0):farr(0,n-1))-vy08(1,0))*3600.	; seq.nos. in farr
;  dtim=tim-shift(tim,1) & dtim(0)=0.	;time differences

;arrays of displacements Dx, Dy, Dr (in km)
Dx=(farr(1,*)-shift(farr(1,*),0,1))*scale & Dx(0)=0
Dy=(farr(2,*)-shift(farr(2,*),0,1))*scale & Dy(0)=0
Dr=sqrt(Dx*Dx+Dy*Dy)

; velocities vx, vy, v
vx=Dx/dtim
vy=Dy/dtim

; FOURIER FILTERING

;  interpolation to 512 equidistant samples in time
dti=(tim(n-1)-tim(1))/512. 	; step in time
tint=findgen(513)*dti+tim(1)    ; tint(0)=tim(1) !
vxi=fltarr(513)
vyi=vxi
vxi(0)=vx(1)
vyi(0)=vy(1)
for i=1,512 do begin		; interpolation of vx,vy
   j=max(where(tint(i) gt (tim+dti/10.)))  ; takes care of trunc.errors
   vxi(i)=vx(j)+(vx(j+1)-vx(j))/(tim(j+1)-tim(j))*(tint(i)-tim(j))
   vyi(i)=vy(j)+(vy(j+1)-vy(j))/(tim(j+1)-tim(j))*(tint(i)-tim(j))
endfor
window,0

filter:
plot,tim,vx,/yst,back=255,col=0
oplot,tim,vy,linestyle=2,col=0
read,'filter cutoff (pixel position):  ',cut

u=fltarr(513)
for i=0,cut do u(i)=(1.-cos(!pi*(cut-i)/cut))/2.
u=[u,reverse(u(1:511))]		; cosinus filter

fvxi=fft([vxi,reverse(vxi(1:511))],-1)*u
fvyi=fft([vyi,reverse(vyi(1:511))],-1)*u
vxif=fft(fvxi,1) & vxif=float(vxif(0:512))
vyif=fft(fvyi,1) & vyif=float(vyif(0:512))
oplot,tint,vxif,col=0
oplot,tint,vyif,linestyle=2,col=0

print,'smoothing ok? (y/n)'
if get_kbrd(1) eq 'n' then goto,filter

;  interpolation back to original sampling
vx1=vx & vy1=vy
vx1(1)=vxif(0)
vy1(1)=vyif(0)
vx1(0)=vx1(1)  ; replication of the first values (no physical sense)
vy1(0)=vy1(1)

for i=2,n-1 do begin
   j=max(where(tim(i) gt tint))
   vx1(i)=vxif(j)+(vxif(j+1)-vxif(j))/(tint(j+1)-tint(j))*(tim(i)-tint(j))
   vy1(i)=vyif(j)+(vyif(j+1)-vyif(j))/(tint(j+1)-tint(j))*(tim(i)-tint(j))
endfor

; computation of errors
evx=0. & evy=0.
for i=1,n-1 do begin
   evx=evx+(vx(i)-vx1(i))*(vx(i)-vx1(i))
   evy=evy+(vy(i)-vy1(i))*(vy(i)-vy1(i))
endfor
evx=evx/((n-1)*(n-2))
evy=evy/((n-1)*(n-2))

print,'errors in vx and vy (km/s):  ',sqrt(evx),sqrt(evy)

vx=vx1 & vy=vy1

oplot,tim,vx,col=0
oplot,tim,vy,linestyle=2,col=0

v=sqrt(vx*vx+vy*vy)	;modulus of filtered velocity

print,'error in v (km/s):',total(sqrt((vx/v)^2*evx+(vy/v)^2*evy))/(n-1)
;print,sqrt((vx/v)^2*evx+(vy/v)^2*evy)

v1=Dr/dtim		;modulus of non-filtered velocity
window,2
plot,tim,v1,linestyle=0,back=255,col=0,xtitle='Time [s]',ytitle='Velocity magnitude [km/s]'
oplot,tim,v,linestyle=2,col=0
wset,0

result=fltarr(8,n)
result(0,*)=farr(0,*)	; seq.no.
result(1,*)=farr(1,*)	; x-position
result(2,*)=farr(2,*)	; y-position
result(3,*)=tim/60.     ; time in minutes from the beginning of series
result(4,*)=vx		; velocities (filtered) - x-component
result(5,*)=vy		;			  y-component
result(6,*)=v		;			  modulus
result(7,*)=farr(3,*)	; intensity

print,'minimum, average, maximum of filtered velocities:'
print,'vx:',min(vx),mean(vx),max(vx)
print,'vy:',min(vy),mean(vy),max(vy)
print,'v: ',min(v),mean(v),max(v)

end
