PRO obrtemp,file,mu,tbg,tbc
;
;Calculates (and plots) brightness temperatures from observed
; intemsities of UDs
;
;INPUTS: 'FILE' = name of 's_*' result file
;	 MU = mu
;OUTPUTS: TBG = array of blue brightness temperatures
;	  TBC = array of red brightness temperatures
;CALLED: CLV
;
; Constants:

wav1 =4507.5		; wavelength 'gc'
wav2 =6020.0		; wavelength 'c6'
iph1o=0.4138		; disk-center absolute intensity for 'gc'
iph2o=0.3095		; disk-center absolute intensity for 'c6'
c1=1.1903e20		; Planck's law
c2=1.4384e8

RESTORE,file
i1=tug(2,*)/10000.
i2=tuc(2,*)/10000.

; Absolute intensities at the position 'mu'

iph1=iph1o*CLV(-1,wav1,mu)
iph2=iph2o*CLV(-1,wav2,mu)

; Brightness temperatures

 a1=alog(c1/(wav1^5*iph1*i1)+1.)
 a2=alog(c1/(wav2^5*iph2*i2)+1.)
 tbg=c2/(wav1*a1)
 tbc=c2/(wav2*a2)

; Statistics

print,' '
print,'BLUE observed brightness:'
STA,i1
print,'MEDIAN =',median(i1)
print,' '
print,'RED observed brightness:'
STA,i2
print,'MEDIAN =',median(i2)

print,' '
print,'BLUE brightness temperatures:'
STA,tbg
print,'MEDIAN =',median(tbg)
print,' '
print,'RED brightness temperatures:'
STA,tbc
print,'MEDIAN =',median(tbc)

plot,tbg,tbc,xra=[4000,7000],yra=[4000,7000],/xst,/yst,psym=1
plots,[4000,7000],[4000,7000]

END


